import os
import toml


PKG_ROOT_DIR=os.path.dirname(__file__)
PKG_STATIC_DIR=os.path.join(PKG_ROOT_DIR,'data','static')
PKG_TEMPLATE_DIR=os.path.join(PKG_ROOT_DIR,'data','templates')



CONFIG=dict(
    DATA_DIR='./',
    HOST='0.0.0.0',
    PORT=8000
)



from sanic import Sanic,response,Blueprint
from . import config as cfg
from .config import CONFIG
from .blueprint import bp_wrappers
import os

def start_server():
    app = Sanic()
    # bp_view=bp_wrappers.wrap_md_viewer(Blueprint('bp_view',url_prefix='/'))
    # app.blueprint(bp_view)
    app=bp_wrappers.wrap_md_viewer(app)
    app.run(host=CONFIG['HOST'],port=CONFIG['PORT'])